{% load i18n cms_tags %}

{% if instance.source_file %}
    <video {{ instance.attributes_str_to_html }} {{ instance.other_attributes_str }}
        {% if instance.poster %} poster="{{ instance.poster.url }}"{% endif %} {{ instance.attributes_str }}>
        {% with instance.source_file.extension as ext %}
            <source src="{{ instance.source_file.url }}" type="video/{{ ext }}" {{ instance.attributes_str }}>
        {% endwith %}
        {% trans "Your browser doesn't support this video format." %}
    </video>
{% else %}
    <p>{% trans 'Video file is missing' %}</p>
{% endif %}
