{% extends CMS_TEMPLATE %}
{% load i18n %}

{% block title %}{% trans "Email confirmation" %}{% endblock %}

{% block content %}
    <p>{% trans "Thank you for your email confirmation. You was logged in automatically." %}</p>
    <p><a href="/">{% trans "Go to homepage" %}</a></p>
{% endblock %}
