{% load i18n cms_tags sekizai_tags %}
{% load static from staticfiles %}

{% addtoblock "css" %}
    <link rel="stylesheet" href="{% static "cms_qe/css/bootstrap.min.css" %}" />
{% endaddtoblock %}

{% addtoblock "js" %}
    <script src="{% static "cms_qe/js/jquery_3.2.1.min.js" %}"></script>
    <script src="{% static "cms_qe/js/bootstrap.min.js" %}"></script>
{% endaddtoblock %}

{# Doctype is important for Django CMS so it can correctly detect height of window. #}
<!DOCTYPE html>

<!--[if IE 9]> <html lang="{{ LANGUAGE_CODE }}" class="ie9"> <![endif]-->
<!--[if !IE]><!--> <html lang="{{ LANGUAGE_CODE }}"> <!--<![endif]-->
    <head>
        <title>{% block title %}{% page_attribute "page_title" %}{% endblock %}</title>
        {% render_block "css" %}

        {% include "cms_qe/include/head.html" %}
    </head>
    <body>
        {% include "cms_qe/include/body_top.html" %}
        {% cms_toolbar %}

        {% block header %}
            <header>
                {% static_placeholder "header" %}
            </header>
        {% endblock %}
        {% block content %}
            {% placeholder "page header" %}
            {% placeholder "content" %}
            {% placeholder "page footer" %}
        {% endblock %}
        {% block footers %}
            <footer>
                {% static_placeholder "footer" %}
            </footer>
        {% endblock %}

        {% render_block "js" %}
        {% include 'cms_qe/include/body_bottom.html' %}
    </body>
</html>
