{% load i18n %}

{% if not instance.table_exists %}
    <p>{% blocktrans with table=instance.table %}Table {{ table }} does not exist!{% endblocktrans %}</p>
{% elif not instance.columns_exist %}
    <p>{% blocktrans %}Some column does not exist!{% endblocktrans %}</p>
{% else %}

    <table>
        {% include "cms_qe/table/table_head.html" %}
        {% include "cms_qe/table/table_body.html" %}
    </table>
    {% include "cms_qe/table/paging.html" %}

{% endif %}
