{% extends CMS_TEMPLATE %}
{% load i18n %}

{% block content %}
    <div>
        <h1>{% trans "Internal error" %}</h1>
        <p>{% blocktrans %}Something went very wrong. Please try again later.{% endblocktrans %}</p>
    </div>
{% endblock %}
