{% extends CMS_TEMPLATE %}
{% load i18n %}

{% block title %}{{ title }}{% endblock %}

{% block content %}
    <p>{% trans "We've emailed you instructions for setting your password, if an account exists with the email you entered. You should receive them shortly." %}</p>
    <p>{% trans "If you don't receive an email, please make sure you've entered the address you registered with, and check your spam folder." %}</p>
{% endblock %}
