# -*- coding: utf-8 -*-
# Generated by Django 1.11.7 on 2017-12-08 09:15
from __future__ import unicode_literals

from django.db import migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('cms_qe_table', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='tablepluginmodel',
            name='filter',
            field=jsonfield.fields.JSONField(default=dict, verbose_name='Filter'),
        ),
    ]
