{% extends CMS_TEMPLATE %}
{% load i18n bootstrap %}

{% block title %}{{ title }}{% endblock %}

{% block content %}
    {% if validlink %}
        <div class="row">
            <div class="col-md-6 col-md-offset-3 col-sm-8 col-sm-offset-2">
                <p>
                    {% trans "Please enter your new password twice so we can verify you typed it in correctly." %}
                </p>
                <form method="post">
                    {% csrf_token %}
                    {{ form|bootstrap }}
                    <input type="submit" class="form-control btn btn-primary" value="{% trans 'Change my password' %}"/>
                </form>
            </div>
        </div>
    {% else %}
        <p>
            {% trans "The password reset link was invalid, possibly because it has already been used.  Please request a new password reset." %}
        </p>
    {% endif %}
{% endblock %}
