{% load i18n bootstrap %}

<div class="modal-dialog">
    <div class="modal-content">
        <div class="modal-header">
            <h1 class="modal-title">{{ title|default:_("Login to Your Account") }}</h1>
        </div>
        <div class="modal-body">
            <form method="post" action="{% url 'login' %}">
                {% csrf_token %}
                <input type="hidden" name="next" value="{{ next }}"/>
                {{ form|bootstrap }}
                <input type="submit" class="form-control btn btn-primary" value="{{ submit|default:_("Login") }}"/>
            </form>
        </div>
        <div class="modal-footer">
            <p>
                <a href="{% url 'register' %}">{% trans "Register" %}</a> &#183;
                <a href="{% url 'password_reset' %}">{% trans "Lost password?" %}</a>
            </p>
        </div>
    </div>
</div>
