{% extends "admin/change_list.html" %}
{% load i18n admin_urls admin_list %}
{% load static from staticfiles %}

{% block object-tools-items %}
    {% if has_add_permission %}
        <li>
            {% url 'sync_mailing_lists' as sync_url %}
            <a href="{% add_preserved_filters sync_url %}">
                {% trans 'Synchronize mailing lists from external sources' %}
            </a>
        </li>
    {% endif %}

    {{ block.super }}
{% endblock %}
