{% load i18n cms_tags cms_qe_video %}

<iframe src="{{ instance.video_url|cms_qe_video_url_to_embed }}?{{ instance.attributes_str_to_url }}"
        {{ instance.size_attributes_str_to_html }} {{ instance.other_attributes_str }}
        frameborder="0" allowfullscreen="true">
</iframe>
{% with disabled=instance.video_url %}
    {% for plugin in instance.child_plugin_instances %}
        {% render_plugin plugin %}
    {% endfor %}
{% endwith %}
