{% load static from staticfiles %}

{% for key, label in languages %}
    {% if language == key %}
        <span title="{{ title }}">{{ key|upper }}</span>
    {% else %}
        <a href="/{{ key }}{{ path }}" title="{{ title }}">{{ key|upper }}</a>
    {% endif %}
    {% if not forloop.last %}|{% endif %}
{% endfor %}
