{% load menu_tags %}

{% if instance.start_page %}
    {% show_menu_below_id instance.start_page 0 instance.end_level instance.extra_inactive instance.extra_active "cms_qe/menu/menu.html" %}
{% else %}
    {% show_menu 0 instance.end_level instance.extra_inactive instance.extra_active "cms_qe/menu/menu.html" %}
{% endif %}