{% extends CMS_TEMPLATE %}
{% load i18n %}

{% block content %}
    <div>
        <h1>{% trans "Generic error" %}</h1>
        <p>{% blocktrans %}You see this page because you didn't configured error page yet. Please add new page with slug <strong>{{ slug }}</strong>.{% endblocktrans %}</p>
    </div>
{% endblock %}
